@@ -281,7 +281,7 @@ def test_Model_getter_param_names(gmodel):
 
 def test_Model__repr__(gmodel):
     """Test for Model class __repr__ method."""
-    assert gmodel.__repr__() == '<lmfit.Model: Model(gaussian)>'
+    assert 'Model(gaussian)' in gmodel.__repr__()
 
 
 def test_Model_copy(gmodel):
@@ -884,10 +884,23 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
         step:  form='linear'
         voigt: gamma=None,     can become a variable!!
         """
-        stepmod = Model(step)
-        assert 'x' in stepmod.independent_vars
-        assert 'form' in stepmod.independent_vars
-        assert 'linear' == stepmod.independent_vars_defvals.get('form', None)
+        stepmod1 = Model(step)
+        assert 'x' in stepmod1.independent_vars
+        assert 'form' in stepmod1.independent_vars
+        assert 'linear' == stepmod1.independent_vars_defvals.get('form', None)
+
+        stepmod2 = Model(step, form='arctan')
+        assert 'x' in stepmod2.independent_vars
+        assert 'form' in stepmod2.independent_vars
+        assert 'arctan' == stepmod2.independent_vars_defvals.get('form', None)
+
+        x = np.linspace(0, 30, 301)
+        pars = stepmod1.make_params(amplitude=10, center=14, sigma=2.5)
+        yline = stepmod1.eval(pars, x=x)
+        yatan = stepmod2.eval(pars, x=x)
+
+        assert (yatan-yline).std() > 0.1
+        assert (yatan-yline).ptp() > 1.0
 
         voigtmod = Model(voigt)
         assert 'x' in voigtmod.independent_vars
@@ -1592,3 +1605,46 @@ def test_rsquared_with_weights():
 
     assert result.rsquared < 1.00
     assert result.rsquared > 0.95
+
+
+# based on Github #953
+class PolynomialFunction:
+    def __init__(self, degree=1):
+        self.degree = degree
+
+    @property
+    def __name__(self):
+        return self.__class__.__name__
+
+    @property
+    def argnames(self):
+        return ["x"] + [f"c{i}" for i in range(self.degree + 1)]
+
+    @property
+    def kwargs(self):
+        return {}
+
+    def __call__(self, x, *coeffs, **params):
+        if len(coeffs) != self.degree + 1:
+            coeffs = [params[f"c{d}"] for d in range(self.degree + 1)]
+        return np.polynomial.polynomial.polyval(x, coeffs)
+
+
+def test_custom_variadic_model():
+    """Github #953"""
+    model = Model(PolynomialFunction(degree=3))
+    params = model.make_params(c0=5, c1=3.6, c2=-0.2, c3=0)
+
+    assert 'x' in model.independent_vars
+
+    np.random.seed(0)
+    x1 = np.linspace(-10, 10, 201)
+    y1 = 5 + 3.3*x1 + 0.17*x1**2 - 0.004*x1**3
+    y1 += np.random.normal(size=201, scale=0.1)
+
+    result = model.fit(y1, params, x=x1)
+
+    assert result.chisqr < 15.0
+    assert result.nfev > 7
+    assert_allclose(result.values['c0'], 5.0, 0.02, 0.02, '', True)
+    assert_allclose(result.values['c1'], 3.3, 0.02, 0.02, '', True)
